Application settings model.
Structs
- Settings
- Application settings stored in redb.
Constants
- CLASSIFICATION_
STORAGE_ MODES - Where to write Verschlusssache / NATO values in the exported CSAF JSON.
- NATO_
LABELS - Allowed NATO classification labels according to https://de.wikipedia.org/wiki/Geheimhaltungsgrad#NATO.
- PUBLISHER_
CATEGORIES - Allowed values for the publisher category dropdown.
- STORAGE_
PATH_ MAX_ LEN - Maximum accepted length (bytes) of a user-supplied storage path.
- TLP_
LABELS - Allowed TLP 2.0 labels (
https://www.first.org/tlp/). - VERSCHLUSSSACHE_
LABELS - Allowed Verschlusssache (German national classification) labels according to https://de.wikipedia.org/wiki/Verschlusssache#Einstufung.
Functions
- is_
valid_ classification_ storage_ mode - Check whether a candidate string is an allowed classification storage mode.
- is_
valid_ nato - Check whether a candidate string is an allowed NATO classification label.
- is_
valid_ publisher_ category - Check whether a candidate string is an allowed publisher category.
- is_
valid_ storage_ path - Check whether a candidate string is an acceptable
filesystem-path setting (
import_directory,export_directory,dump_directory). - is_
valid_ tlp - Check whether a candidate string is an allowed TLP 2.0 label.
- is_
valid_ verschlusssache - Check whether a candidate string is an allowed Verschlusssache label.