Module settings

Module settings 

Application settings model.

Structs

Settings
Application settings stored in redb.

Constants

CLASSIFICATION_STORAGE_MODES
Where to write Verschlusssache / NATO values in the exported CSAF JSON.
NATO_LABELS
Allowed NATO classification labels according to https://de.wikipedia.org/wiki/Geheimhaltungsgrad#NATO.
PUBLISHER_CATEGORIES
Allowed values for the publisher category dropdown.
STORAGE_PATH_MAX_LEN
Maximum accepted length (bytes) of a user-supplied storage path.
TLP_LABELS
Allowed TLP 2.0 labels (https://www.first.org/tlp/).
VERSCHLUSSSACHE_LABELS
Allowed Verschlusssache (German national classification) labels according to https://de.wikipedia.org/wiki/Verschlusssache#Einstufung.

Functions

is_valid_classification_storage_mode
Check whether a candidate string is an allowed classification storage mode.
is_valid_nato
Check whether a candidate string is an allowed NATO classification label.
is_valid_publisher_category
Check whether a candidate string is an allowed publisher category.
is_valid_storage_path
Check whether a candidate string is an acceptable filesystem-path setting (import_directory, export_directory, dump_directory).
is_valid_tlp
Check whether a candidate string is an allowed TLP 2.0 label.
is_valid_verschlusssache
Check whether a candidate string is an allowed Verschlusssache label.